==> nhanesA_0.7.2.tar.gz: nhanesA/NEWS.md <==
Version 0.7.2
================================================================================

- Add includewithdrawn flag to nhanesSearchTableNames (thanks @Ifitrains https://github.com/cjendres1/nhanes/issues/15). Updated README. 

Version 0.7.1
================================================================================

- Add function nhanesCodebook (thanks @paynejason https://github.com/cjendres1/nhanes/issues/9, 
and @rsgoncalves  https://github.com/cjendres1/nhanes/issues/11)

Version 0.7.0
================================================================================

- Apply more thorough error checking of read_html. Remove function calls from the vignette.

Version 0.6.7.2
================================================================================

- Add badges, add NEWS.md, update hex sticker (thanks Angela Endres!)

Version 0.6.7
================================================================================

- Enable access to pre-pandemic data (thanks @jennyguadamuz, https://github.com/cjendres1/nhanes/issues/8).

Version 0.6.5.3
================================================================================

- Fixed a bug in nhanesSearch and updated misleading code in the vignette (thanks @rpouillot,
https://github.com/cjendres1/nhanes/issues/6)

Version 0.6.5
================================================================================

- Updated search functions to accommodate reorganization of the NHANES website (thanks @Drinkysr, https://github.com/cjendres1/nhanes/issues/4)

Version 0.6.4.1
================================================================================

- Updated vignette to accommodate changes to NHANES html (thanks @dhicks, https://github.com/cjendres1/nhanes/issues/3)

==> nhanesA_0.7.3.tar.gz: nhanesA/NEWS.md <==
Version 0.7.3
================================================================================

- Updated nhanesTableVars to be compatible with pre-pandemic tables (thanks @lamisipam https://github.com/cjendres1/nhanes/issues/16).

Version 0.7.2 
================================================================================

- Add includewithdrawn flag to nhanesSearchTableNames (thanks @Ifitrains https://github.com/cjendres1/nhanes/issues/15). Updated README. 

Version 0.7.1
================================================================================

- Add function nhanesCodebook (thanks @paynejason https://github.com/cjendres1/nhanes/issues/9, 
and @rsgoncalves  https://github.com/cjendres1/nhanes/issues/11)

Version 0.7.0
================================================================================

- Apply more thorough error checking of read_html. Remove function calls from the vignette.

Version 0.6.7.2
================================================================================

- Add badges, add NEWS.md, update hex sticker (thanks Angela Endres!)

Version 0.6.7
================================================================================

- Enable access to pre-pandemic data (thanks @jennyguadamuz, https://github.com/cjendres1/nhanes/issues/8).

Version 0.6.5.3
================================================================================

- Fixed a bug in nhanesSearch and updated misleading code in the vignette (thanks @rpouillot,
https://github.com/cjendres1/nhanes/issues/6)

Version 0.6.5
================================================================================

- Updated search functions to accommodate reorganization of the NHANES website (thanks @Drinkysr, https://github.com/cjendres1/nhanes/issues/4)

Version 0.6.4.1
================================================================================

- Updated vignette to accommodate changes to NHANES html (thanks @dhicks, https://github.com/cjendres1/nhanes/issues/3)
